@@ -82,6 +82,10 @@ def get_settings(environment: Optional[str], log_level: str):
             "datasource_rf_url": os.getenv(
                 "SNATCH_DATASOURCE_RF_URL", "http://datasource_pep"
             ),
+            "data_risk_secret_token": os.getenv("SNATCH_DATA_RISK_SECRET_TOKEN", "foo"),
+            "datasource_data_risk_url": os.getenv(
+                "SNATCH_DATASOURCE_DATA_RISK_URL", "http://datasource_data_risk"
+            ),
         }
     }
     config.update(
